NodeSet

Struct NodeSet 

pub struct NodeSet { /* private fields */ }
Node set implementation using a bit set

Since nodes are stored in an array, we can use a single bit vector. This reduces space consumption dramatically and increases the performance.